@@ -128,7 +128,9 @@ struct RBSongInfoPrivate
 	GtkWidget   *composer;
 	GtkWidget   *genre;
 	GtkWidget   *track_cur;
+	GtkWidget   *track_total;
 	GtkWidget   *disc_cur;
+	GtkWidget   *disc_total;
 	GtkWidget   *year;
 	GtkWidget   *comment;
 	GtkTextBuffer *comment_buffer;
@@ -349,7 +351,7 @@ static void
 rb_song_info_construct_single (RBSongInfo *song_info, GtkBuilder *builder, gboolean editable)
 {
 	song_info->priv->backward = gtk_dialog_add_button (GTK_DIALOG (song_info),
-							   GTK_STOCK_GO_BACK,
+							   _("_Back"),
 							   GTK_RESPONSE_NONE);
 
 	g_signal_connect_object (G_OBJECT (song_info->priv->backward),
@@ -358,7 +360,7 @@ rb_song_info_construct_single (RBSongInfo *song_info, GtkBuilder *builder, gbool
 				 song_info, 0);
 
 	song_info->priv->forward = gtk_dialog_add_button (GTK_DIALOG (song_info),
-							   GTK_STOCK_GO_FORWARD,
+							   _("_Forward"),
 							   GTK_RESPONSE_NONE);
 
 	g_signal_connect_object (G_OBJECT (song_info->priv->forward),
@@ -501,7 +503,9 @@ rb_song_info_constructed (GObject *object)
 	song_info->priv->year = GTK_WIDGET (gtk_builder_get_object (builder, "song_info_year"));
 	song_info->priv->playback_error_box = GTK_WIDGET (gtk_builder_get_object (builder, "song_info_error_box"));
 	song_info->priv->playback_error_label = GTK_WIDGET (gtk_builder_get_object (builder, "song_info_error_label"));
+	song_info->priv->track_total   = GTK_WIDGET (gtk_builder_get_object (builder, "song_info_track_total"));
 	song_info->priv->disc_cur = GTK_WIDGET (gtk_builder_get_object (builder, "song_info_disc_cur"));
+	song_info->priv->disc_total = GTK_WIDGET (gtk_builder_get_object (builder, "song_info_disc_total"));
 
 	song_info->priv->artist_sortname = GTK_WIDGET (gtk_builder_get_object (builder, "song_info_artist_sortname"));
 	song_info->priv->album_sortname = GTK_WIDGET (gtk_builder_get_object (builder, "song_info_album_sortname"));
@@ -519,7 +523,9 @@ rb_song_info_constructed (GObject *object)
 	rb_builder_boldify_label (builder, "genre_label");
 	rb_builder_boldify_label (builder, "year_label");
 	rb_builder_boldify_label (builder, "rating_label");
+	rb_builder_boldify_label (builder, "track_total_label");
 	rb_builder_boldify_label (builder, "discn_label");
+	rb_builder_boldify_label (builder, "disc_total_label");
 	rb_builder_boldify_label (builder, "artist_sortname_label");
 	rb_builder_boldify_label (builder, "album_sortname_label");
 	rb_builder_boldify_label (builder, "album_artist_sortname_label");
@@ -549,10 +555,18 @@ rb_song_info_constructed (GObject *object)
 				 "mnemonic-activate",
 				 G_CALLBACK (rb_song_info_mnemonic_cb),
 				 NULL, 0);
+	g_signal_connect_object (G_OBJECT (song_info->priv->track_total),
+				 "mnemonic-activate",
+				 G_CALLBACK (rb_song_info_mnemonic_cb),
+				 NULL, 0);
 	g_signal_connect_object (G_OBJECT (song_info->priv->disc_cur),
 				 "mnemonic-activate",
 				 G_CALLBACK (rb_song_info_mnemonic_cb),
 				 NULL, 0);
+	g_signal_connect_object (G_OBJECT (song_info->priv->disc_total),
+				 "mnemonic-activate",
+				 G_CALLBACK (rb_song_info_mnemonic_cb),
+				 NULL, 0);
 	g_signal_connect_object (G_OBJECT (song_info->priv->artist_sortname),
 				 "mnemonic-activate",
 				 G_CALLBACK (rb_song_info_mnemonic_cb),
@@ -592,7 +606,9 @@ rb_song_info_constructed (GObject *object)
 	gtk_editable_set_editable (GTK_EDITABLE (song_info->priv->composer), editable);
 	gtk_editable_set_editable (GTK_EDITABLE (song_info->priv->genre), editable);
 	gtk_editable_set_editable (GTK_EDITABLE (song_info->priv->year), editable);
+	gtk_editable_set_editable (GTK_EDITABLE (song_info->priv->track_total), editable);
 	gtk_editable_set_editable (GTK_EDITABLE (song_info->priv->disc_cur), editable);
+	gtk_editable_set_editable (GTK_EDITABLE (song_info->priv->disc_total), editable);
 
 	/* Finish construction */
 	if (song_info->priv->current_entry) {
@@ -608,7 +624,7 @@ rb_song_info_constructed (GObject *object)
 	g_object_unref (G_OBJECT (shell));
 
 	gtk_dialog_add_button (GTK_DIALOG (song_info),
-			       GTK_STOCK_CLOSE,
+			       _("_Close"),
 			       GTK_RESPONSE_CLOSE);
 
 	gtk_dialog_set_default_response (GTK_DIALOG (song_info),
@@ -956,7 +972,9 @@ rb_song_info_populate_dialog_multiple (RBSongInfo *song_info)
 	gboolean mixed_composers = FALSE;
 	gboolean mixed_genres = FALSE;
 	gboolean mixed_years = FALSE;
+	gboolean mixed_track_totals = FALSE;
 	gboolean mixed_disc_numbers = FALSE;
+	gboolean mixed_disc_totals = FALSE;
 	gboolean mixed_ratings = FALSE;
 	gboolean mixed_artist_sortnames = FALSE;
 	gboolean mixed_album_sortnames = FALSE;
@@ -968,7 +986,9 @@ rb_song_info_populate_dialog_multiple (RBSongInfo *song_info)
 	const char *composer = NULL;
 	const char *genre = NULL;
 	int year = 0;
+	int track_total = 0;
 	int disc_number = 0;
+	int disc_total = 0;
 	double rating = 0.0; /* Zero is used for both "unrated" and "mixed ratings" too */
 	const char *artist_sortname = NULL;
 	const char *album_sortname = NULL;
@@ -986,7 +1006,9 @@ rb_song_info_populate_dialog_multiple (RBSongInfo *song_info)
 		const char *entry_composer;
 		const char *entry_genre;
 		int entry_year;
+		int entry_track_total;
 		int entry_disc_number;
+		int entry_disc_total;
 		double entry_rating;
 		const char *entry_artist_sortname;
 		const char *entry_album_sortname;
@@ -1000,7 +1022,9 @@ rb_song_info_populate_dialog_multiple (RBSongInfo *song_info)
 		entry_composer = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_COMPOSER);
 		entry_genre = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_GENRE);
 		entry_year = rhythmdb_entry_get_ulong (entry, RHYTHMDB_PROP_YEAR);
+		entry_track_total = rhythmdb_entry_get_ulong (entry, RHYTHMDB_PROP_TRACK_TOTAL);
 		entry_disc_number = rhythmdb_entry_get_ulong (entry, RHYTHMDB_PROP_DISC_NUMBER);
+		entry_disc_total = rhythmdb_entry_get_ulong (entry, RHYTHMDB_PROP_DISC_TOTAL);
 		entry_rating = rhythmdb_entry_get_double (entry, RHYTHMDB_PROP_RATING);
 		entry_artist_sortname = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_ARTIST_SORTNAME);
 		entry_album_sortname = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_ALBUM_SORTNAME);
@@ -1020,8 +1044,12 @@ rb_song_info_populate_dialog_multiple (RBSongInfo *song_info)
 			genre = entry_genre;
 		if (year == 0)
 			year = entry_year;
+		if (track_total == 0)
+			track_total = entry_track_total;
 		if (disc_number == 0)
 			disc_number = entry_disc_number;
+		if (disc_total == 0)
+			disc_total = entry_disc_total;
 		if (fabs(rating) < EPSILON)
 			rating = entry_rating;
 		if (artist_sortname == NULL)
@@ -1046,8 +1074,12 @@ rb_song_info_populate_dialog_multiple (RBSongInfo *song_info)
 			mixed_genres = TRUE;
 		if (year != entry_year)
 			mixed_years = TRUE;
+		if (track_total != entry_track_total)
+			mixed_track_totals = TRUE;
 		if (disc_number != entry_disc_number)
 			mixed_disc_numbers = TRUE;
+		if (disc_total != entry_disc_total)
+			mixed_disc_totals = TRUE;
 		if (fabs(rating - entry_rating) >= EPSILON)
 			mixed_ratings = TRUE;
 		if (artist_sortname != entry_artist_sortname)
@@ -1062,7 +1094,8 @@ rb_song_info_populate_dialog_multiple (RBSongInfo *song_info)
 		/* don't continue search if everything is mixed */
 		if (mixed_artists && mixed_albums && mixed_album_artists &&
 		    mixed_composers && mixed_genres && mixed_years &&
-		    mixed_disc_numbers && mixed_ratings &&
+		    mixed_track_totals && mixed_disc_numbers &&
+		    mixed_disc_totals && mixed_ratings &&
 		    mixed_artist_sortnames && mixed_album_sortnames &&
 		    mixed_album_artist_sortnames && mixed_composer_sortnames)
 			break;
@@ -1080,8 +1113,12 @@ rb_song_info_populate_dialog_multiple (RBSongInfo *song_info)
 		gtk_entry_set_text (GTK_ENTRY (song_info->priv->genre), genre);
 	if (!mixed_years && year != 0)
 		rb_song_info_populate_num_field (GTK_ENTRY (song_info->priv->year), year);
+	if (!mixed_track_totals && track_total != 0)
+		rb_song_info_populate_num_field (GTK_ENTRY (song_info->priv->track_total), track_total);
 	if (!mixed_disc_numbers && disc_number != 0)
 		rb_song_info_populate_num_field (GTK_ENTRY (song_info->priv->disc_cur), disc_number);
+	if (!mixed_disc_totals && disc_total != 0)
+		rb_song_info_populate_num_field (GTK_ENTRY (song_info->priv->disc_total), disc_total);
 	if (!mixed_ratings && fabs(rating) >= EPSILON)
 		g_object_set (G_OBJECT (song_info->priv->rating), "rating", rating, NULL);
 	if (!mixed_artist_sortnames && artist_sortname != NULL)
@@ -1127,8 +1164,12 @@ rb_song_info_populate_dialog (RBSongInfo *song_info)
 
 	num = rhythmdb_entry_get_ulong (song_info->priv->current_entry, RHYTHMDB_PROP_TRACK_NUMBER);
 	rb_song_info_populate_num_field (GTK_ENTRY (song_info->priv->track_cur), num);
+	num = rhythmdb_entry_get_ulong (song_info->priv->current_entry, RHYTHMDB_PROP_TRACK_TOTAL);
+	rb_song_info_populate_num_field (GTK_ENTRY (song_info->priv->track_total), num);
 	num = rhythmdb_entry_get_ulong (song_info->priv->current_entry, RHYTHMDB_PROP_DISC_NUMBER);
 	rb_song_info_populate_num_field (GTK_ENTRY (song_info->priv->disc_cur), num);
+	num = rhythmdb_entry_get_ulong (song_info->priv->current_entry, RHYTHMDB_PROP_DISC_TOTAL);
+	rb_song_info_populate_num_field (GTK_ENTRY (song_info->priv->disc_total), num);
 	dnum = rhythmdb_entry_get_double (song_info->priv->current_entry, RHYTHMDB_PROP_BPM);
 	rb_song_info_populate_dnum_field (GTK_ENTRY (song_info->priv->bpm), dnum);
 	text = rhythmdb_entry_get_string (song_info->priv->current_entry, RHYTHMDB_PROP_COMMENT);
@@ -1543,7 +1584,7 @@ rb_song_info_update_date_added (RBSongInfo *song_info)
 }
 
 static gboolean
-sync_string_property (RBSongInfo *dialog, RhythmDBPropType property, GtkWidget *entry)
+sync_string_property_multiple (RBSongInfo *dialog, RhythmDBPropType property, GtkWidget *entry)
 {
 	const char *new_text;
 	GValue val = {0,};
@@ -1572,29 +1613,62 @@ sync_string_property (RBSongInfo *dialog, RhythmDBPropType property, GtkWidget *
 	return changed;
 }
 
+static gboolean
+sync_ulong_property_multiple (RBSongInfo *dialog, RhythmDBPropType property, GtkWidget *entry)
+{
+	const char *new_text;
+	gint val_int;
+	GValue val = {0,};
+	GList *tem;
+	gboolean changed = FALSE;
+	char *endptr;
+
+	new_text = gtk_entry_get_text (GTK_ENTRY (entry));
+	val_int = g_ascii_strtoull (new_text, &endptr, 10);
+
+	if (endptr != new_text) {
+
+		g_value_init (&val, G_TYPE_ULONG);
+		g_value_set_ulong (&val, val_int);
+
+		for (tem = dialog->priv->selected_entries; tem; tem = tem->next) {
+			RhythmDBEntry *dbentry;
+			gulong entry_num;
+
+			dbentry = (RhythmDBEntry *)tem->data;
+			entry_num = rhythmdb_entry_get_ulong (dbentry, property);
+
+			if (val_int != entry_num) {
+				rhythmdb_entry_set (dialog->priv->db, dbentry,
+						    property, &val);
+				changed = TRUE;
+			}
+		}
+		g_value_unset (&val);
+	}
+	return changed;
+}
+
 static void
 rb_song_info_sync_entries_multiple (RBSongInfo *dialog)
 {
 	const char *year_str = gtk_entry_get_text (GTK_ENTRY (dialog->priv->year));
-	const char *discn_str = gtk_entry_get_text (GTK_ENTRY (dialog->priv->disc_cur));
-
 	char *endptr;
 	GValue val = {0,};
 	GList *tem;
 	gint year;
-	gint discn;
 	gboolean changed = FALSE;
 	RhythmDBEntry *entry;
 
-	changed |= sync_string_property (dialog, RHYTHMDB_PROP_ALBUM, dialog->priv->album);
-	changed |= sync_string_property (dialog, RHYTHMDB_PROP_ARTIST, dialog->priv->artist);
-	changed |= sync_string_property (dialog, RHYTHMDB_PROP_ALBUM_ARTIST, dialog->priv->album_artist);
-	changed |= sync_string_property (dialog, RHYTHMDB_PROP_COMPOSER, dialog->priv->composer);
-	changed |= sync_string_property (dialog, RHYTHMDB_PROP_GENRE, dialog->priv->genre);
-	changed |= sync_string_property (dialog, RHYTHMDB_PROP_ARTIST_SORTNAME, dialog->priv->artist_sortname);
-	changed |= sync_string_property (dialog, RHYTHMDB_PROP_ALBUM_SORTNAME, dialog->priv->album_sortname);
-	changed |= sync_string_property (dialog, RHYTHMDB_PROP_ALBUM_ARTIST_SORTNAME, dialog->priv->album_artist_sortname);
-	changed |= sync_string_property (dialog, RHYTHMDB_PROP_COMPOSER_SORTNAME, dialog->priv->composer_sortname);
+	changed |= sync_string_property_multiple (dialog, RHYTHMDB_PROP_ALBUM, dialog->priv->album);
+	changed |= sync_string_property_multiple (dialog, RHYTHMDB_PROP_ARTIST, dialog->priv->artist);
+	changed |= sync_string_property_multiple (dialog, RHYTHMDB_PROP_ALBUM_ARTIST, dialog->priv->album_artist);
+	changed |= sync_string_property_multiple (dialog, RHYTHMDB_PROP_COMPOSER, dialog->priv->composer);
+	changed |= sync_string_property_multiple (dialog, RHYTHMDB_PROP_GENRE, dialog->priv->genre);
+	changed |= sync_string_property_multiple (dialog, RHYTHMDB_PROP_ARTIST_SORTNAME, dialog->priv->artist_sortname);
+	changed |= sync_string_property_multiple (dialog, RHYTHMDB_PROP_ALBUM_SORTNAME, dialog->priv->album_sortname);
+	changed |= sync_string_property_multiple (dialog, RHYTHMDB_PROP_ALBUM_ARTIST_SORTNAME, dialog->priv->album_artist_sortname);
+	changed |= sync_string_property_multiple (dialog, RHYTHMDB_PROP_COMPOSER_SORTNAME, dialog->priv->composer_sortname);
 
 	if (strlen (year_str) > 0) {
 		GDate *date = NULL;
@@ -1623,33 +1697,58 @@ rb_song_info_sync_entries_multiple (RBSongInfo *dialog)
 
 	}
 
-	discn = g_ascii_strtoull (discn_str, &endptr, 10);
-	if (endptr != discn_str) {
-		GType type;
-		type = rhythmdb_get_property_type (dialog->priv->db,
-						   RHYTHMDB_PROP_DISC_NUMBER);
-		g_value_init (&val, type);
-		g_value_set_ulong (&val, discn);
-
-		for (tem = dialog->priv->selected_entries; tem; tem = tem->next) {
-			gulong entry_disc_num;
-
-			entry = (RhythmDBEntry *)tem->data;
-			entry_disc_num = rhythmdb_entry_get_ulong (entry, RHYTHMDB_PROP_DISC_NUMBER);
-
-			if (discn != entry_disc_num) {
-				rhythmdb_entry_set (dialog->priv->db, entry,
-						    RHYTHMDB_PROP_DISC_NUMBER, &val);
-				changed = TRUE;
-			}
-		}
-		g_value_unset (&val);
-	}
+	changed |= sync_ulong_property_multiple (dialog, RHYTHMDB_PROP_TRACK_TOTAL, dialog->priv->track_total);
+	changed |= sync_ulong_property_multiple (dialog, RHYTHMDB_PROP_DISC_NUMBER, dialog->priv->disc_cur);
+	changed |= sync_ulong_property_multiple (dialog, RHYTHMDB_PROP_DISC_TOTAL, dialog->priv->disc_total);
 
 	if (changed)
 		rhythmdb_commit (dialog->priv->db);
 }
 
+static gboolean
+sync_property_ulong_single (RBSongInfo *dialog,
+			    RhythmDBEntry *entry,
+			    guint property,
+			    GtkWidget *w)
+{
+	char *endptr;
+
+	const char *new_text = gtk_entry_get_text (GTK_ENTRY (w));
+	gulong prop_val = g_ascii_strtoull (new_text, &endptr, 10);
+	gulong entry_val = rhythmdb_entry_get_ulong (entry, property);
+
+	if ((endptr != new_text) && (prop_val != entry_val)) {
+		GValue val = {0,};
+
+		g_value_init (&val, G_TYPE_ULONG);
+		g_value_set_ulong (&val, prop_val);
+		rhythmdb_entry_set (dialog->priv->db, entry, property, &val);
+
+		return TRUE;
+	}
+	return FALSE;
+}
+
+static gboolean
+sync_property_string_single (RBSongInfo *dialog,
+			     RhythmDBEntry *dbentry,
+			     guint property,
+			     const gchar *prop_val)
+{
+	const char *entry_string = rhythmdb_entry_get_string (dbentry,
+							      property);
+	if (g_strcmp0 (prop_val, entry_string)) {
+		GValue val = {0,};
+
+		g_value_init (&val, G_TYPE_STRING);
+		g_value_set_string (&val, prop_val);
+		rhythmdb_entry_set (dialog->priv->db, dbentry,
+				    property, &val);
+		return TRUE;
+	}
+	return FALSE;
+}
+
 static void
 rb_song_info_sync_entry_single (RBSongInfo *dialog)
 {
@@ -1659,20 +1758,15 @@ rb_song_info_sync_entry_single (RBSongInfo *dialog)
 	const char *album;
 	const char *album_artist;
 	const char *composer;
-	const char *tracknum_str;
-	const char *discnum_str;
 	const char *year_str;
 	const char *artist_sortname;
 	const char *album_sortname;
 	const char *album_artist_sortname;
 	const char *composer_sortname;
-	const char *entry_string;
 	const char *bpm_str;
 	char *comment = NULL;
 	char *endptr;
 	GType type;
-	gulong tracknum;
-	gulong discnum;
 	gulong year;
 	gulong entry_val;
 	gdouble bpm;
@@ -1688,8 +1782,6 @@ rb_song_info_sync_entry_single (RBSongInfo *dialog)
 	album = gtk_entry_get_text (GTK_ENTRY (dialog->priv->album));
 	album_artist = gtk_entry_get_text (GTK_ENTRY (dialog->priv->album_artist));
 	composer = gtk_entry_get_text (GTK_ENTRY (dialog->priv->composer));
-	tracknum_str = gtk_entry_get_text (GTK_ENTRY (dialog->priv->track_cur));
-	discnum_str = gtk_entry_get_text (GTK_ENTRY (dialog->priv->disc_cur));
 	year_str = gtk_entry_get_text (GTK_ENTRY (dialog->priv->year));
 	artist_sortname = gtk_entry_get_text (GTK_ENTRY (dialog->priv->artist_sortname));
 	album_sortname = gtk_entry_get_text (GTK_ENTRY (dialog->priv->album_sortname));
@@ -1703,29 +1795,22 @@ rb_song_info_sync_entry_single (RBSongInfo *dialog)
 	g_signal_emit (dialog, rb_song_info_signals[PRE_METADATA_CHANGE], 0,
 		       entry);
 
-	tracknum = g_ascii_strtoull (tracknum_str, &endptr, 10);
-	entry_val = rhythmdb_entry_get_ulong (entry, RHYTHMDB_PROP_TRACK_NUMBER);
-	if ((endptr != tracknum_str) && (tracknum != entry_val)) {
-		type = rhythmdb_get_property_type (dialog->priv->db,
-						   RHYTHMDB_PROP_TRACK_NUMBER);
-		g_value_init (&val, type);
-		g_value_set_ulong (&val, tracknum);
-		rhythmdb_entry_set (dialog->priv->db, entry, RHYTHMDB_PROP_TRACK_NUMBER, &val);
-		g_value_unset (&val);
-		changed = TRUE;
-	}
-
-	discnum = g_ascii_strtoull (discnum_str, &endptr, 10);
-	entry_val = rhythmdb_entry_get_ulong (entry, RHYTHMDB_PROP_DISC_NUMBER);
-	if ((endptr != discnum_str) && (discnum != entry_val)) {
-		type = rhythmdb_get_property_type (dialog->priv->db,
-						   RHYTHMDB_PROP_DISC_NUMBER);
-		g_value_init (&val, type);
-		g_value_set_ulong (&val, discnum);
-		rhythmdb_entry_set (dialog->priv->db, entry, RHYTHMDB_PROP_DISC_NUMBER, &val);
-		g_value_unset (&val);
-		changed = TRUE;
-	}
+	changed |= sync_property_ulong_single (dialog,
+					       entry,
+					       RHYTHMDB_PROP_TRACK_NUMBER,
+					       dialog->priv->track_cur);
+	changed |= sync_property_ulong_single (dialog,
+					       entry,
+					       RHYTHMDB_PROP_TRACK_TOTAL,
+					       dialog->priv->track_total);
+	changed |= sync_property_ulong_single (dialog,
+					       entry,
+					       RHYTHMDB_PROP_DISC_NUMBER,
+					       dialog->priv->disc_cur);
+	changed |= sync_property_ulong_single (dialog,
+					       entry,
+					       RHYTHMDB_PROP_DISC_TOTAL,
+					       dialog->priv->disc_total);
 
 	year = g_ascii_strtoull (year_str, &endptr, 10);
 	entry_val = rhythmdb_entry_get_ulong (entry, RHYTHMDB_PROP_YEAR);
@@ -1769,137 +1854,18 @@ rb_song_info_sync_entry_single (RBSongInfo *dialog)
 		g_value_unset (&val);
 		changed = TRUE;
 	}
-	entry_string = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_TITLE);
-	if (g_strcmp0 (title, entry_string)) {
-		type = rhythmdb_get_property_type (dialog->priv->db,
-						   RHYTHMDB_PROP_TITLE);
-		g_value_init (&val, type);
-		g_value_set_string (&val, title);
-		rhythmdb_entry_set (dialog->priv->db, entry,
-				    RHYTHMDB_PROP_TITLE, &val);
-		g_value_unset (&val);
-		changed = TRUE;
-	}
 
-	entry_string = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_ALBUM);
-	if (g_strcmp0 (album, entry_string)) {
-		type = rhythmdb_get_property_type (dialog->priv->db,
-						   RHYTHMDB_PROP_ALBUM);
-		g_value_init (&val, type);
-		g_value_set_string (&val, album);
-		rhythmdb_entry_set (dialog->priv->db, entry,
-				    RHYTHMDB_PROP_ALBUM, &val);
-		g_value_unset (&val);
-		changed = TRUE;
-	}
-
-	entry_string = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_ARTIST);
-	if (g_strcmp0 (artist, entry_string)) {
-		type = rhythmdb_get_property_type (dialog->priv->db,
-						   RHYTHMDB_PROP_ARTIST);
-		g_value_init (&val, type);
-		g_value_set_string (&val, artist);
-		rhythmdb_entry_set (dialog->priv->db, entry,
-				    RHYTHMDB_PROP_ARTIST, &val);
-		g_value_unset (&val);
-		changed = TRUE;
-	}
-
-	entry_string = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_ALBUM_ARTIST);
-	if (g_strcmp0 (album_artist, entry_string)) {
-		type = rhythmdb_get_property_type (dialog->priv->db,
-						   RHYTHMDB_PROP_ALBUM_ARTIST);
-		g_value_init (&val, type);
-		g_value_set_string (&val, album_artist);
-		rhythmdb_entry_set (dialog->priv->db, entry,
-				    RHYTHMDB_PROP_ALBUM_ARTIST, &val);
-		g_value_unset (&val);
-		changed = TRUE;
-	}
-
-	entry_string = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_COMPOSER);
-	if (g_strcmp0 (composer, entry_string)) {
-		type = rhythmdb_get_property_type (dialog->priv->db,
-						   RHYTHMDB_PROP_COMPOSER);
-		g_value_init (&val, type);
-		g_value_set_string (&val, composer);
-		rhythmdb_entry_set (dialog->priv->db, entry,
-				    RHYTHMDB_PROP_COMPOSER, &val);
-		g_value_unset (&val);
-		changed = TRUE;
-	}
-
-	entry_string = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_GENRE);
-	if (g_strcmp0 (genre, entry_string)) {
-		type = rhythmdb_get_property_type (dialog->priv->db,
-						   RHYTHMDB_PROP_GENRE);
-		g_value_init (&val, type);
-		g_value_set_string (&val, genre);
-		rhythmdb_entry_set (dialog->priv->db, entry,
-				    RHYTHMDB_PROP_GENRE, &val);
-		g_value_unset (&val);
-		changed = TRUE;
-	}
-
-	entry_string = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_ARTIST_SORTNAME);
-	if (g_strcmp0 (artist_sortname, entry_string)) {
-		type = rhythmdb_get_property_type (dialog->priv->db,
-						   RHYTHMDB_PROP_ARTIST_SORTNAME);
-		g_value_init (&val, type);
-		g_value_set_string (&val, artist_sortname);
-		rhythmdb_entry_set (dialog->priv->db, entry,
-				    RHYTHMDB_PROP_ARTIST_SORTNAME, &val);
-		g_value_unset (&val);
-		changed = TRUE;
-	}
-
-	entry_string = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_ALBUM_SORTNAME);
-	if (g_strcmp0 (album_sortname, entry_string)) {
-		type = rhythmdb_get_property_type (dialog->priv->db,
-						   RHYTHMDB_PROP_ALBUM_SORTNAME);
-		g_value_init (&val, type);
-		g_value_set_string (&val, album_sortname);
-		rhythmdb_entry_set (dialog->priv->db, entry,
-				    RHYTHMDB_PROP_ALBUM_SORTNAME, &val);
-		g_value_unset (&val);
-		changed = TRUE;
-	}
-
-	entry_string = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_COMMENT);
-	if (g_strcmp0 (comment, entry_string)) {
-		type = rhythmdb_get_property_type (dialog->priv->db,
-						   RHYTHMDB_PROP_COMMENT);
-		g_value_init (&val, type);
-		g_value_set_string (&val, comment);
-		rhythmdb_entry_set (dialog->priv->db, entry,
-				    RHYTHMDB_PROP_COMMENT, &val);
-		g_value_unset (&val);
-		changed = TRUE;
-	}
-
-	entry_string = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_ALBUM_ARTIST_SORTNAME);
-	if (g_strcmp0 (album_artist_sortname, entry_string)) {
-		type = rhythmdb_get_property_type (dialog->priv->db,
-						   RHYTHMDB_PROP_ALBUM_ARTIST_SORTNAME);
-		g_value_init (&val, type);
-		g_value_set_string (&val, album_artist_sortname);
-		rhythmdb_entry_set (dialog->priv->db, entry,
-				    RHYTHMDB_PROP_ALBUM_ARTIST_SORTNAME, &val);
-		g_value_unset (&val);
-		changed = TRUE;
-	}
-
-	entry_string = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_COMPOSER_SORTNAME);
-	if (g_strcmp0 (composer_sortname, entry_string)) {
-		type = rhythmdb_get_property_type (dialog->priv->db,
-						   RHYTHMDB_PROP_COMPOSER_SORTNAME);
-		g_value_init (&val, type);
-		g_value_set_string (&val, composer_sortname);
-		rhythmdb_entry_set (dialog->priv->db, entry,
-				    RHYTHMDB_PROP_COMPOSER_SORTNAME, &val);
-		g_value_unset (&val);
-		changed = TRUE;
-	}
+	changed |= sync_property_string_single (dialog, entry, RHYTHMDB_PROP_TITLE, title);
+	changed |= sync_property_string_single (dialog, entry, RHYTHMDB_PROP_ALBUM, album);
+	changed |= sync_property_string_single (dialog, entry, RHYTHMDB_PROP_ARTIST, artist);
+	changed |= sync_property_string_single (dialog, entry, RHYTHMDB_PROP_ALBUM_ARTIST, album_artist);
+	changed |= sync_property_string_single (dialog, entry, RHYTHMDB_PROP_COMPOSER, composer);
+	changed |= sync_property_string_single (dialog, entry, RHYTHMDB_PROP_GENRE, genre);
+	changed |= sync_property_string_single (dialog, entry, RHYTHMDB_PROP_ARTIST_SORTNAME, artist_sortname);
+	changed |= sync_property_string_single (dialog, entry, RHYTHMDB_PROP_ALBUM_SORTNAME, album_sortname);
+	changed |= sync_property_string_single (dialog, entry, RHYTHMDB_PROP_COMMENT, comment);
+	changed |= sync_property_string_single (dialog, entry, RHYTHMDB_PROP_ALBUM_ARTIST_SORTNAME, album_artist_sortname);
+	changed |= sync_property_string_single (dialog, entry, RHYTHMDB_PROP_COMPOSER_SORTNAME, composer_sortname);
 
 	/* FIXME: when an entry is SYNCed, a changed signal is emitted, and
 	 * this signal is also emitted, aren't they redundant?
